---
name: Bug report
about: Create a report to help us improve
title: "[BUG] Title of the bug"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Outputs**
If applicable, add the output to help explain your problem.

**Environment:**
 - conda list
 - pip list
 - grayskull --version

**Additional context**
Add any other context about the problem here.
